@@ -35,60 +35,107 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Module class for displaying a user's recently used/favorite tools
  */
-class modToolList extends \Hubzero\Module\Module
+class modToolList extends JObject
 {
+	/**
+	 * Container for properties
+	 * 
+	 * @var array
+	 */
+	private $attributes = array();
+
+	/**
+	 * Constructor
+	 * 
+	 * @param      object $params JParameter
+	 * @param      object $module Database row
+	 * @return     void
+	 */
+	public function __construct($params, $module)
+	{
+		$this->params = $params;
+		$this->module = $module;
+	}
+
+	/**
+	 * Set a property
+	 * 
+	 * @param      string $property Name of property to set
+	 * @param      mixed  $value    Value to set property to
+	 * @return     void
+	 */
+	public function __set($property, $value)
+	{
+		$this->attributes[$property] = $value;
+	}
+
+	/**
+	 * Get a property
+	 * 
+	 * @param      string $property Name of property to retrieve
+	 * @return     mixed
+	 */
+	public function __get($property)
+	{
+		if (isset($this->attributes[$property])) 
+		{
+			return $this->attributes[$property];
+		}
+	}
+
 	/**
 	 * Get a list of applications that the user might invoke.
-	 *
+	 * 
 	 * @param      array $lst Parameter description (if any) ...
 	 * @return     array Return description (if any) ...
 	 */
 	private function _getToollist($lst=NULL)
 	{
-		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'models' . DS . 'tool.php');
+		ximport('Hubzero_Tool');
+		ximport('Hubzero_Tool_Version');
 
 		$toollist = array();
 
 		// Create a Tool object
 		$database = JFactory::getDBO();
 
-		if (is_array($lst))
+		if (is_array($lst)) 
 		{
 			$tools = array();
 			// Check if the list is empty or not
-			if (!empty($lst))
+			if (!empty($lst)) 
 			{
 				ksort($lst);
 				$items = array();
 				// Get info for tools in the list
 				foreach ($lst as $item)
 				{
-					if (strstr($item, '_r'))
+					if (strstr($item, '_r')) 
 					{
 						$bits = explode('_r', $item);
 						$rev = (is_array($bits) && count($bits > 1)) ? array_pop($bits) : '';
 						$item = trim(implode('_r', $bits));
 					}
-					/*$thistool = ToolsModelVersion::getVersionInfo('', 'current', $item, '');
+					/*$thistool = Hubzero_Tool_Version::getVersionInfo('', 'current', $item, '');
 
-					if (is_array($thistool) && isset($thistool[0]))
+					if (is_array($thistool) && isset($thistool[0])) 
 					{
 						$t = $thistool[0];
 						$tools[] = $t;
 					}*/
 					$items[] = $item;
 				}
-				$tools = ToolsModelVersion::getVersionInfo('', 'current', $items, '');
-			}
-			else
+				$tools = Hubzero_Tool_Version::getVersionInfo('', 'current', $items, '');
+			} 
+			else 
 			{
 				return array();
 			}
-		}
-		else
+		} 
+		else 
 		{
 			// Get all available tools
-			$tools = ToolsModelTool::getMyTools();
+			$tools = Hubzero_Tool::getMyTools();
 		}
 
 		$toolnames = array();
@@ -96,7 +143,7 @@ class modToolList extends \Hubzero\Module\Module
 		// Turn it into an App array.
 		foreach ($tools as $tool)
 		{
-			if (!in_array(strtolower($tool->toolname), $toolnames))
+			if (!in_array(strtolower($tool->toolname), $toolnames)) 
 			{
 				// include only one version
 				$toollist[strtolower($tool->instance)] = new MwModApp(
@@ -118,7 +165,7 @@ class modToolList extends \Hubzero\Module\Module
 
 	/**
 	 * Convert quote marks
-	 *
+	 * 
 	 * @param      string $txt Text to convert quotes in
 	 * @return     string
 	 */
@@ -131,18 +178,18 @@ class modToolList extends \Hubzero\Module\Module
 
 	/**
 	 * Build the HTML for a list of tools
-	 *
+	 * 
 	 * @param      array  &$toollist List of tools to format
 	 * @param      string $type      Type of list being formatted
 	 * @return     string HTML
 	 */
 	public function buildList($toollist, $type='all')
 	{
-		if ($type == 'favs')
+		if ($type == 'favs') 
 		{
 			$favs = array();
-		}
-		elseif ($type == 'all')
+		} 
+		elseif ($type == 'all') 
 		{
 			$favs = $this->favs;
 		}
@@ -150,16 +197,16 @@ class modToolList extends \Hubzero\Module\Module
 		$database = JFactory::getDBO();
 
 		$html  = "\t\t" . '<ul>' . "\n";
-		if (count($toollist) <= 0)
+		if (count($toollist) <= 0) 
 		{
 			$html .= "\t\t" . ' <li>' . JText::_('MOD_MYTOOLS_NONE_FOUND') . '</li>' . "\n";
-		}
-		else
+		} 
+		else 
 		{
 			foreach ($toollist as $tool)
 			{
 				// Make sure we have some info before attempting to display it
-				if (!empty($tool->caption))
+				if (!empty($tool->caption)) 
 				{
 					// Prep the text for XHTML output
 					$tool->caption = $this->_prepText($tool->caption);
@@ -171,39 +218,23 @@ class modToolList extends \Hubzero\Module\Module
 
 					// from sep 28-07 version (svn revision) number is supplied at the end of the invoke command
 					//$url = 'index.php?option=com_mw&task=invoke&sess='.$tool->name.'&version='.$tool->revision;
-
-					//are we on the iPad
-					/*$isiPad = (bool) strpos($_SERVER['HTTP_USER_AGENT'], 'iPad');
-
-					//get tool params
-					$params = JComponentHelper::getParams('com_tools');
-					$launchOnIpad = $params->get('launch_ipad', 0);
-
-					//if we are on the ipad and we want to launch nanohub app
-					if ($isiPad && $launchOnIpad)
-					{
-						$url = 'nanohub://tools/invoke/' . $tool->toolname . '/' . $tool->revision;
-					}
-					else
-					{*/
-						$url = JRoute::_('index.php?option=com_tools&controller=sessions&task=invoke&app='.$tool->toolname.'&version='.$tool->revision);
-					//}
+					$url = 'index.php?option=com_tools&task=invoke&app='.$tool->toolname.'&version='.$tool->revision;
 
 					$cls = '';
 					// Build the HTML
 					$html .= "\t\t" . ' <li id="'.$tool->name.'"';
 					// If we're in the 'all tools' pane ...
-					if ($type == 'all')
+					if ($type == 'all') 
 					{
 						// Highlight tools on the user's favorites list
-						if (in_array($tool->name,$favs))
+						if (in_array($tool->name,$favs)) 
 						{
 							$cls = 'favd';
 						}
 					}
-					if ($this->supportedtag)
+					if ($this->supportedtag) 
 					{
-						if (in_array($tool->toolname, $this->supportedtagusage))
+						if (in_array($tool->toolname, $this->supportedtagusage)) 
 						{
 							$cls .= ($cls) ? ' supported' : 'supported';
 						}
@@ -212,27 +243,25 @@ class modToolList extends \Hubzero\Module\Module
 					$html .= '>' . "\n";
 
 					// Tool info link
-					$html .= "\t\t\t" . ' <a href="'.JRoute::_('index.php?option=com_tools&controller=pipeline&app=' . $tool->toolname).'" class="tooltips" title="'.$tool->caption.' :: '.$tool->desc.'">'.$tool->caption.'</a>' . "\n";
+					$html .= "\t\t\t" . ' <a href="/tools/'.$tool->toolname.'" class="tooltips" title="'.$tool->caption.' :: '.$tool->desc.'">'.$tool->caption.'</a>' . "\n";
 
 					// Only add the "favorites" button to the all tools list
-					if ($type == 'all')
+					if ($type == 'all') 
 					{
-						$html .= "\t\t\t" . ' <a href="javascript:void(0);" class="fav" title="'.JText::sprintf('MOD_MYTOOLS_ADD_TO_FAVORITES', $tool->caption).'">'.$tool->caption.'</a>' . "\n";
+						$html .= "\t\t\t" . ' <a href="javascript:void(0);" class="fav" title="Add '.$tool->caption.' to your favorites">'.$tool->caption.'</a>' . "\n";
 					}
 
 					// Launch tool link
-					if ($this->can_launch && $tool->middleware != 'download')
+					if ($this->can_launch) 
 					{
-
-
-						$html .= "\t\t\t" . ' <a href="'.$url.'" class="launchtool" title="'.JText::sprintf('MOD_MYTOOLS_LAUNCH_TOOL', $tool->caption).'">'.JText::sprintf('MOD_MYTOOLS_LAUNCH_TOOL', $tool->caption).'</a>' . "\n";
+						$html .= "\t\t\t" . ' <a href="'.$url.'" class="launchtool" title="Launch '.$tool->caption.'">Launch '.$tool->caption.'</a>' . "\n";
 					}
 					$html .= "\t\t" . ' </li>' . "\n";
 				}
 				// If we're in the 'favorites' pane ...
-				// Add the tool's name to an array for the 'all tools'
+				// Add the tool's name to an array for the 'all tools' 
 				// pane to use in highlighting favorite tools
-				if ($type == 'favs')
+				if ($type == 'favs') 
 				{
 					$favs[] = $tool->name;
 				}
@@ -240,26 +269,34 @@ class modToolList extends \Hubzero\Module\Module
 		}
 		$html .= "\t\t" . '</ul>' . "\n";
 
-		// if ($type == 'favs')
-		// {
-		// 	$this->favs = $favs;
-		// }
+		if ($type == 'favs') 
+		{
+			$this->favs = $favs;
+		}
 		return $html;
 	}
 
 	/**
 	 * Display module content
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function display()
 	{
-		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'helpers' . DS . 'utils.php');
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'models' . DS . 'mw.utils.php');
 		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'models' . DS . 'mw.class.php');
 		include_once(JPATH_ROOT . DS . 'modules' . DS . $this->module->module . DS . 'app.php');
 
 		$params = $this->params;
 
+		if (version_compare(JVERSION, '1.6', 'lt'))
+		{
+			$jacl = JFactory::getACL();
+			$jacl->addACL('com_tools', 'manage', 'users', 'super administrator');
+			$jacl->addACL('com_tools', 'manage', 'users', 'administrator');
+			$jacl->addACL('com_tools', 'manage', 'users', 'manager');
+		}
+
 		$juser = JFactory::getUser();
 
 		$mconfig = JComponentHelper::getParams('com_tools');
@@ -267,7 +304,7 @@ class modToolList extends \Hubzero\Module\Module
 		// Ensure we have a connection to the middleware
 		$this->can_launch = true;
 		if (!$mconfig->get('mw_on')
-		 || ($mconfig->get('mw_on') > 1 && !$juser->authorize('com_tools', 'manage')))
+		 || ($mconfig->get('mw_on') > 1 && !$juser->authorize('com_tools', 'manage'))) 
 		{
 			$this->can_launch = false;
 		}
@@ -280,15 +317,15 @@ class modToolList extends \Hubzero\Module\Module
 		$rconfig = JComponentHelper::getParams('com_resources');
 		$this->supportedtag = $rconfig->get('supportedtag');
 
-		$database = JFactory::getDBO();
-		if ($this->supportedtag)
+		$database =& JFactory::getDBO();
+		if ($this->supportedtag) 
 		{
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'helpers' . DS . 'tags.php');
-			$this->rt = new ResourcesTags(0);
+			$this->rt = new ResourcesTags($database);
 			$this->supportedtagusage = $this->rt->getTagUsage($this->supportedtag, 'alias');
 		}
 
-		if ($this->fav || $this->no_html)
+		if ($this->fav || $this->no_html) 
 		{
 			// We have a string of tools! This means we're updating the
 			// favorite tools pane of the module via AJAX
@@ -296,20 +333,25 @@ class modToolList extends \Hubzero\Module\Module
 			$favs = array_map('trim', $favs);
 
 			$this->favtools = ($this->fav) ? $this->_getToollist($favs) : array();
-		}
-		else
+		} 
+		else 
 		{
 			$juser = JFactory::getUser();
 
 			// Add the JavaScript that does the AJAX magic to the template
 			$document = JFactory::getDocument();
 
+			// Push the module CSS to the template
+			ximport('Hubzero_Document');
+			Hubzero_Document::addModuleStyleSheet($this->module->module);
+			Hubzero_Document::addModuleScript($this->module->module);
+
 			// Get a list of recent tools
 			$rt = new RecentTool($database);
 			$rows = $rt->getRecords($juser->get('id'));
 
 			$recent = array();
-			if (!empty($rows))
+			if (!empty($rows)) 
 			{
 				foreach ($rows as $row)
 				{
@@ -318,12 +360,12 @@ class modToolList extends \Hubzero\Module\Module
 			}
 
 			// Get the user's list of favorites
-			$fav = $params->get('favs');
-			if ($fav)
+			$fav = $params->get('myhub_favs');
+			if ($fav) 
 			{
 				$favs = explode(',', $fav);
-			}
-			else
+			} 
+			else 
 			{
 				$favs = array();
 			}
